==> Botan-1.1.13.tgz: Botan-1.1.13/include/rsa.h <==
/*************************************************
* RSA Header File                                *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#ifndef BOTAN_RSA_H__
#define BOTAN_RSA_H__

#include <botan/if_algo.h>
#include <botan/pk_keys.h>

namespace Botan {

/*************************************************
* RSA Public Key                                 *
*************************************************/
class RSA_PublicKey : public PK_Encrypting_Key,
                      public PK_Verifying_with_MR_Key,
                      public virtual IF_Scheme_PublicKey
   {
   public:
      SecureVector<byte> encrypt(const byte[], u32bit) const;
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      RSA_PublicKey(const BigInt&, const BigInt&);
      RSA_PublicKey(DataSource&, X509_Encoding = PEM);
   protected:
      RSA_PublicKey() {}
   private:
      friend X509_PublicKey* get_public_key(const std::string&);
      std::string algo_name() const;
      BigInt public_op(const BigInt&) const;
   };

/*************************************************
* RSA Private Key                                *
*************************************************/
class RSA_PrivateKey : public RSA_PublicKey, public PK_Decrypting_Key,
                       public PK_Signing_Key, public IF_Scheme_PrivateKey
   {
   public:
      SecureVector<byte> decrypt(const byte[], u32bit) const;
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;

      RSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                     const BigInt& = 0, const BigInt& = 0);
      RSA_PrivateKey(u32bit, const BigInt& = 65537);
      RSA_PrivateKey(DataSource&, const std::string& = "",
                     X509_Encoding = PEM);
   private:
      friend PKCS8_PrivateKey* get_private_key(const std::string&);
      RSA_PrivateKey() {}
   };

}

#endif

==> Botan-1.3.5.tgz: Botan-1.3.5/include/rsa.h <==
/*************************************************
* RSA Header File                                *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#ifndef BOTAN_RSA_H__
#define BOTAN_RSA_H__

#include <botan/if_algo.h>
#include <botan/pk_keys.h>

namespace Botan {

/*************************************************
* RSA Public Key                                 *
*************************************************/
class RSA_PublicKey : public PK_Encrypting_Key,
                      public PK_Verifying_with_MR_Key,
                      public virtual IF_Scheme_PublicKey
   {
   public:
      SecureVector<byte> encrypt(const byte[], u32bit) const;
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      RSA_PublicKey(const BigInt&, const BigInt&);
   protected:
      std::string algo_name() const;
      RSA_PublicKey() {}
   private:
      friend X509_PublicKey* get_public_key(const std::string&);
      BigInt public_op(const BigInt&) const;
   };

/*************************************************
* RSA Private Key                                *
*************************************************/
class RSA_PrivateKey : public RSA_PublicKey, public PK_Decrypting_Key,
                       public PK_Signing_Key, public IF_Scheme_PrivateKey
   {
   public:
      SecureVector<byte> decrypt(const byte[], u32bit) const;
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;

      RSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                     const BigInt& = 0, const BigInt& = 0);
      RSA_PrivateKey(u32bit, u32bit = 65537);
   private:
      friend PKCS8_PrivateKey* get_private_key(const std::string&);
      RSA_PrivateKey() {}
   };

}

#endif
